symengine: A C++ symbolic manipulation library
==============================================

Description
-----------

SymEngine is a standalone fast C++ symbolic manipulation library.

License
-------

BSD 3-clause

Upstream Contact
----------------

https://github.com/symengine/symengine
